# emeki

This is my first python package published on PyPI.
Install as follows.

```
$ pip install emeki
```

[![CircleCI](https://circleci.com/gh/chbauman/emeki.svg?style=svg)](https://circleci.com/gh/chbauman/emeki)
